var _scripts =
[
    [ "Loading scripts", "_scripts.html#autotoc_md63", null ],
    [ "Format", "_scripts.html#Format", [
      [ "Script Inheritance", "_scripts.html#Script-Inheritance", [
        [ "Advanced Script Inheritance", "_scripts.html#Advanced-Script-Inheritance", null ]
      ] ],
      [ "Script Variables", "_scripts.html#Script-Variables", null ],
      [ "Script Import Directive", "_scripts.html#Script-Import-Directive", null ]
    ] ],
    [ "Custom Translators", "_scripts.html#custom-translators", null ],
    [ "Material Scripts", "_material-_scripts.html", [
      [ "Material", "_material-_scripts.html#Material", [
        [ "lod_strategy", "_material-_scripts.html#autotoc_md110", null ],
        [ "lod_values", "_material-_scripts.html#autotoc_md111", null ],
        [ "lod_distances", "_material-_scripts.html#autotoc_md112", null ],
        [ "receive_shadows", "_material-_scripts.html#autotoc_md113", null ],
        [ "transparency_casts_shadows", "_material-_scripts.html#autotoc_md114", null ],
        [ "set_texture_alias", "_material-_scripts.html#autotoc_md115", null ]
      ] ],
      [ "Techniques", "_material-_scripts.html#Techniques", [
        [ "scheme", "_material-_scripts.html#autotoc_md116", null ],
        [ "lod_index", "_material-_scripts.html#autotoc_md117", null ],
        [ "shadow_caster_material", "_material-_scripts.html#autotoc_md118", null ],
        [ "shadow_receiver_material", "_material-_scripts.html#autotoc_md119", null ],
        [ "gpu_vendor_rule and gpu_device_rule", "_material-_scripts.html#autotoc_md120", null ]
      ] ],
      [ "Passes", "_material-_scripts.html#Passes", null ],
      [ "Attribute Descriptions", "_material-_scripts.html#autotoc_md121", [
        [ "ambient", "_material-_scripts.html#autotoc_md122", null ],
        [ "diffuse", "_material-_scripts.html#autotoc_md123", null ],
        [ "specular", "_material-_scripts.html#autotoc_md124", null ],
        [ "emissive", "_material-_scripts.html#autotoc_md125", null ],
        [ "scene_blend", "_material-_scripts.html#autotoc_md126", null ],
        [ "separate_scene_blend", "_material-_scripts.html#autotoc_md127", null ],
        [ "scene_blend_op", "_material-_scripts.html#autotoc_md128", null ],
        [ "separate_scene_blend_op", "_material-_scripts.html#autotoc_md129", null ],
        [ "depth_check", "_material-_scripts.html#autotoc_md130", null ],
        [ "depth_write", "_material-_scripts.html#autotoc_md131", null ],
        [ "depth_func", "_material-_scripts.html#autotoc_md132", null ],
        [ "depth_bias", "_material-_scripts.html#autotoc_md133", null ],
        [ "iteration_depth_bias", "_material-_scripts.html#autotoc_md134", null ],
        [ "alpha_rejection", "_material-_scripts.html#autotoc_md135", null ],
        [ "alpha_to_coverage", "_material-_scripts.html#autotoc_md136", null ],
        [ "light_scissor", "_material-_scripts.html#autotoc_md137", null ],
        [ "light_clip_planes", "_material-_scripts.html#autotoc_md138", null ],
        [ "illumination_stage", "_material-_scripts.html#illumination_005fstage", null ],
        [ "transparent_sorting", "_material-_scripts.html#autotoc_md139", null ],
        [ "cull_hardware", "_material-_scripts.html#autotoc_md140", null ],
        [ "cull_software", "_material-_scripts.html#autotoc_md141", null ],
        [ "lighting", "_material-_scripts.html#autotoc_md142", null ],
        [ "shading", "_material-_scripts.html#autotoc_md143", null ],
        [ "polygon_mode", "_material-_scripts.html#autotoc_md144", null ],
        [ "polygon_mode_overrideable", "_material-_scripts.html#autotoc_md145", null ],
        [ "fog_override", "_material-_scripts.html#autotoc_md146", null ],
        [ "colour_write", "_material-_scripts.html#autotoc_md147", null ],
        [ "start_light", "_material-_scripts.html#autotoc_md148", null ],
        [ "max_lights", "_material-_scripts.html#autotoc_md149", null ],
        [ "iteration", "_material-_scripts.html#iteration", null ],
        [ "point_size", "_material-_scripts.html#autotoc_md150", null ],
        [ "point_sprites", "_material-_scripts.html#autotoc_md151", null ],
        [ "point_size_attenuation", "_material-_scripts.html#autotoc_md152", null ],
        [ "point_size_min", "_material-_scripts.html#autotoc_md153", null ],
        [ "point_size_max", "_material-_scripts.html#autotoc_md154", null ],
        [ "line_width", "_material-_scripts.html#autotoc_md155", null ]
      ] ],
      [ "Texture Units", "_material-_scripts.html#Texture-Units", [
        [ "Available Texture Unit Attributes", "_material-_scripts.html#autotoc_md156", null ],
        [ "Attribute Descriptions", "_material-_scripts.html#autotoc_md157", null ],
        [ "texture_alias", "_material-_scripts.html#autotoc_md158", null ],
        [ "texture", "_material-_scripts.html#autotoc_md159", null ],
        [ "anim_texture", "_material-_scripts.html#autotoc_md160", null ],
        [ "cubic_texture", "_material-_scripts.html#autotoc_md161", null ],
        [ "content_type", "_material-_scripts.html#autotoc_md162", null ],
        [ "tex_coord_set", "_material-_scripts.html#autotoc_md163", null ],
        [ "colour_op", "_material-_scripts.html#autotoc_md164", null ],
        [ "colour_op_ex", "_material-_scripts.html#autotoc_md165", null ],
        [ "colour_op_multipass_fallback", "_material-_scripts.html#autotoc_md166", null ],
        [ "alpha_op_ex", "_material-_scripts.html#autotoc_md167", null ],
        [ "env_map", "_material-_scripts.html#autotoc_md168", null ],
        [ "scroll", "_material-_scripts.html#autotoc_md169", null ],
        [ "scroll_anim", "_material-_scripts.html#autotoc_md170", null ],
        [ "rotate", "_material-_scripts.html#autotoc_md171", null ],
        [ "rotate_anim", "_material-_scripts.html#autotoc_md172", null ],
        [ "scale", "_material-_scripts.html#autotoc_md173", null ],
        [ "wave_xform", "_material-_scripts.html#autotoc_md174", null ],
        [ "transform", "_material-_scripts.html#autotoc_md175", null ],
        [ "sampler_ref", "_material-_scripts.html#autotoc_md176", null ],
        [ "unordered_access_mip", "_material-_scripts.html#autotoc_md177", null ]
      ] ],
      [ "Samplers", "_material-_scripts.html#Samplers", [
        [ "Available parameters", "_material-_scripts.html#autotoc_md178", null ],
        [ "tex_address_mode", "_material-_scripts.html#autotoc_md179", null ],
        [ "tex_border_colour", "_material-_scripts.html#autotoc_md180", null ],
        [ "filtering", "_material-_scripts.html#autotoc_md181", [
          [ "Simple Format", "_material-_scripts.html#autotoc_md182", null ],
          [ "Complex Format", "_material-_scripts.html#autotoc_md183", null ]
        ] ],
        [ "max_anisotropy", "_material-_scripts.html#autotoc_md184", null ],
        [ "mipmap_bias", "_material-_scripts.html#autotoc_md185", null ],
        [ "compare_test", "_material-_scripts.html#autotoc_md186", null ],
        [ "comp_func", "_material-_scripts.html#autotoc_md187", null ]
      ] ],
      [ "Using GPU Programs in a Pass", "_material-_scripts.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass", null ],
      [ "Adding new Techniques, Passes, to copied materials", "_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a", null ],
      [ "Identifying Texture Units to override values", "_material-_scripts.html#Identifying-Texture-Units-to-override-values", null ]
    ] ],
    [ "GPU Program Scripts", "_high-level-_programs.html", [
      [ "Default Program Parameters", "_high-level-_programs.html#Default-Program-Parameters", null ],
      [ "High Level Programs", "_high-level-_programs.html#autotoc_md188", [
        [ "Preprocessor definitions", "_high-level-_programs.html#Preprocessor-definitions", null ],
        [ "Entry Point", "_high-level-_programs.html#autotoc_md189", null ]
      ] ],
      [ "GLSL programs", "_high-level-_programs.html#GLSL", [
        [ "Binding vertex attributes", "_high-level-_programs.html#Binding-vertex-attributes", null ],
        [ "Buffers in Mesh Shaders", "_high-level-_programs.html#GLSL-Mesh-Shaders", null ],
        [ "Binding Texture Samplers", "_high-level-_programs.html#GLSL-Texture-Samplers", null ],
        [ "Matrix parameters", "_high-level-_programs.html#Matrix-parameters", null ],
        [ "Uniform Buffers", "_high-level-_programs.html#Uniform-Buffers", null ],
        [ "Transform Feedback Varyings", "_high-level-_programs.html#Transform-Feedback-Varyings", null ],
        [ "Compatibility profile GLSL features", "_high-level-_programs.html#Legacy-GLSL-features", [
          [ "OpenGL state", "_high-level-_programs.html#autotoc_md190", null ],
          [ "Built-in attributes", "_high-level-_programs.html#autotoc_md191", null ],
          [ "Geometry shader in/ out", "_high-level-_programs.html#autotoc_md192", null ],
          [ "Multi module shaders", "_high-level-_programs.html#autotoc_md193", null ]
        ] ]
      ] ],
      [ "Cg programs", "_high-level-_programs.html#Cg", null ],
      [ "DirectX HLSL", "_high-level-_programs.html#HLSL", null ],
      [ "Assembler Shaders", "_high-level-_programs.html#Assembler-Shaders", [
        [ "Specifying Named Constants", "_high-level-_programs.html#Specifying-Named-Constants-for-Assembler-Shaders", null ]
      ] ],
      [ "Multi-language Programs", "_high-level-_programs.html#multi-language-programs", null ],
      [ "Unified High-level Programs", "_high-level-_programs.html#Unified-High_002dlevel-Programs", null ],
      [ "Parameter specification", "_high-level-_programs.html#Program-Parameter-Specification", [
        [ "param_indexed", "_high-level-_programs.html#autotoc_md194", null ],
        [ "param_indexed_auto", "_high-level-_programs.html#autotoc_md195", null ],
        [ "param_named", "_high-level-_programs.html#autotoc_md196", null ],
        [ "param_named_auto", "_high-level-_programs.html#autotoc_md197", null ],
        [ "shared_params_ref", "_high-level-_programs.html#autotoc_md198", null ],
        [ "use_linear_colours", "_high-level-_programs.html#autotoc_md199", null ]
      ] ],
      [ "Declaring Shared Parameters", "_high-level-_programs.html#Declaring-Shared-Parameters", [
        [ "Hardware Support", "_high-level-_programs.html#autotoc_md200", null ]
      ] ],
      [ "Shadows and Vertex Programs", "_high-level-_programs.html#Shadows-and-Vertex-Programs", null ],
      [ "Instancing in Vertex Programs", "_high-level-_programs.html#Instancing-in-Vertex-Programs", null ],
      [ "Skeletal Animation in Vertex Programs", "_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs", null ],
      [ "Morph Animation in Vertex Programs", "_high-level-_programs.html#Morph-Animation-in-Vertex-Programs", null ],
      [ "Pose Animation in Vertex Programs", "_high-level-_programs.html#Pose-Animation-in-Vertex-Programs", null ],
      [ "Vertex Texture Fetch", "_high-level-_programs.html#Vertex-Texture-Fetch", [
        [ "Declaring the use of vertex texture fetching", "_high-level-_programs.html#autotoc_md201", null ],
        [ "DirectX9 binding limitations", "_high-level-_programs.html#autotoc_md202", null ],
        [ "Texture format limitations", "_high-level-_programs.html#autotoc_md203", null ],
        [ "Hardware limitations", "_high-level-_programs.html#autotoc_md204", null ]
      ] ],
      [ "Programmatic creation", "_high-level-_programs.html#GpuProgram-API", null ]
    ] ],
    [ "Compositor Scripts", "_compositor-_scripts.html", [
      [ "Compositor Fundamentals", "_compositor-_scripts.html#Compositor-Fundamentals", null ],
      [ "Techniques", "_compositor-_scripts.html#Compositor-Techniques", [
        [ "texture", "_compositor-_scripts.html#compositor-texture", null ],
        [ "texture_ref", "_compositor-_scripts.html#autotoc_md64", null ],
        [ "scheme", "_compositor-_scripts.html#autotoc_md65", null ],
        [ "compositor_logic", "_compositor-_scripts.html#autotoc_md66", null ]
      ] ],
      [ "Target Sections", "_compositor-_scripts.html#Compositor-Target-Passes", [
        [ "input", "_compositor-_scripts.html#autotoc_md67", null ],
        [ "only_initial", "_compositor-_scripts.html#autotoc_md68", null ],
        [ "visibility_mask", "_compositor-_scripts.html#autotoc_md69", null ],
        [ "lod_bias", "_compositor-_scripts.html#autotoc_md70", null ],
        [ "shadows", "_compositor-_scripts.html#autotoc_md71", null ],
        [ "material_scheme", "_compositor-_scripts.html#autotoc_md72", null ]
      ] ],
      [ "Passes", "_compositor-_scripts.html#Compositor-Passes", [
        [ "render_quad &amp; compute", "_compositor-_scripts.html#autotoc_md73", [
          [ "material", "_compositor-_scripts.html#autotoc_md74", null ],
          [ "input", "_compositor-_scripts.html#autotoc_md75", null ],
          [ "identifier", "_compositor-_scripts.html#autotoc_md76", null ],
          [ "quad_normals", "_compositor-_scripts.html#autotoc_md77", null ],
          [ "thread_groups", "_compositor-_scripts.html#autotoc_md78", null ]
        ] ],
        [ "render_scene", "_compositor-_scripts.html#autotoc_md79", [
          [ "first_render_queue", "_compositor-_scripts.html#autotoc_md80", null ],
          [ "last_render_queue", "_compositor-_scripts.html#autotoc_md81", null ],
          [ "material_scheme", "_compositor-_scripts.html#autotoc_md82", null ],
          [ "camera", "_compositor-_scripts.html#autotoc_md83", null ]
        ] ],
        [ "clear", "_compositor-_scripts.html#Clear-Section", [
          [ "buffers", "_compositor-_scripts.html#autotoc_md84", null ],
          [ "colour_value", "_compositor-_scripts.html#autotoc_md85", null ],
          [ "depth_value", "_compositor-_scripts.html#autotoc_md86", null ],
          [ "stencil_value", "_compositor-_scripts.html#autotoc_md87", null ]
        ] ],
        [ "stencil", "_compositor-_scripts.html#Stencil-Section", [
          [ "check", "_compositor-_scripts.html#autotoc_md88", null ],
          [ "comp_func", "_compositor-_scripts.html#autotoc_md89", null ],
          [ "ref_value", "_compositor-_scripts.html#autotoc_md90", null ],
          [ "mask", "_compositor-_scripts.html#autotoc_md91", null ],
          [ "fail_op", "_compositor-_scripts.html#autotoc_md92", null ],
          [ "depth_fail_op", "_compositor-_scripts.html#autotoc_md93", null ],
          [ "pass_op", "_compositor-_scripts.html#autotoc_md94", null ],
          [ "two_sided", "_compositor-_scripts.html#autotoc_md95", null ]
        ] ]
      ] ],
      [ "Applying a Compositor", "_compositor-_scripts.html#Applying-a-Compositor", null ],
      [ "Programmatic creation", "_compositor-_scripts.html#Compositor-API", null ]
    ] ],
    [ "Particle Scripts", "_particle-_scripts.html", [
      [ "Particle System Attributes", "_particle-_scripts.html#Particle-System-Attributes", [
        [ "quota", "_particle-_scripts.html#autotoc_md207", null ],
        [ "material", "_particle-_scripts.html#autotoc_md208", null ],
        [ "particle_width", "_particle-_scripts.html#autotoc_md209", null ],
        [ "particle_height", "_particle-_scripts.html#autotoc_md210", null ],
        [ "cull_each", "_particle-_scripts.html#autotoc_md211", null ],
        [ "renderer", "_particle-_scripts.html#autotoc_md212", null ],
        [ "sorted", "_particle-_scripts.html#autotoc_md213", null ],
        [ "local_space", "_particle-_scripts.html#autotoc_md214", null ],
        [ "iteration_interval", "_particle-_scripts.html#autotoc_md215", null ],
        [ "nonvisible_update_timeout", "_particle-_scripts.html#autotoc_md216", null ]
      ] ],
      [ "Billboard Renderer Attributes", "_particle-_scripts.html#Billboard-Renderer-Attributes", [
        [ "billboard_type", "_particle-_scripts.html#autotoc_md217", null ],
        [ "billboard_origin", "_particle-_scripts.html#autotoc_md218", null ],
        [ "billboard_rotation_type", "_particle-_scripts.html#autotoc_md219", null ],
        [ "common_direction", "_particle-_scripts.html#autotoc_md220", null ],
        [ "common_up_vector", "_particle-_scripts.html#autotoc_md221", null ],
        [ "point_rendering", "_particle-_scripts.html#autotoc_md222", null ],
        [ "accurate_facing", "_particle-_scripts.html#autotoc_md223", null ],
        [ "texture_sheet_size", "_particle-_scripts.html#autotoc_md224", null ]
      ] ],
      [ "Particle Emitters", "_particle-_scripts.html#Particle-Emitters", [
        [ "Emitting Emitters", "_particle-_scripts.html#Emitting-Emitters", null ],
        [ "Common Emitter Attributes", "_particle-_scripts.html#autotoc_md225", null ],
        [ "angle", "_particle-_scripts.html#autotoc_md226", null ],
        [ "colour", "_particle-_scripts.html#autotoc_md227", null ],
        [ "colour_range_start &amp; colour_range_end", "_particle-_scripts.html#autotoc_md228", null ],
        [ "direction", "_particle-_scripts.html#autotoc_md229", null ],
        [ "direction_position_reference", "_particle-_scripts.html#autotoc_md230", null ],
        [ "emission_rate", "_particle-_scripts.html#autotoc_md231", null ],
        [ "position", "_particle-_scripts.html#autotoc_md232", null ],
        [ "velocity", "_particle-_scripts.html#autotoc_md233", null ],
        [ "velocity_min &amp; velocity_max", "_particle-_scripts.html#autotoc_md234", null ],
        [ "time_to_live", "_particle-_scripts.html#autotoc_md235", null ],
        [ "time_to_live_min &amp; time_to_live_max", "_particle-_scripts.html#autotoc_md236", null ],
        [ "duration", "_particle-_scripts.html#autotoc_md237", null ],
        [ "duration_min &amp; duration_max", "_particle-_scripts.html#autotoc_md238", null ],
        [ "repeat_delay", "_particle-_scripts.html#autotoc_md239", null ],
        [ "repeat_delay_min &amp; repeat_delay_max", "_particle-_scripts.html#autotoc_md240", null ]
      ] ],
      [ "Standard Particle Emitters", "_particle-_scripts.html#Standard-Particle-Emitters", [
        [ "Point Emitter", "_particle-_scripts.html#Point-Emitter", null ],
        [ "Box Emitter", "_particle-_scripts.html#Box-Emitter", null ],
        [ "Cylinder Emitter", "_particle-_scripts.html#Cylinder-Emitter", null ],
        [ "Ellipsoid Emitter", "_particle-_scripts.html#Ellipsoid-Emitter", null ],
        [ "Hollow Ellipsoid Emitter", "_particle-_scripts.html#Hollow-Ellipsoid-Emitter", null ],
        [ "Ring Emitter", "_particle-_scripts.html#Ring-Emitter", null ]
      ] ],
      [ "Particle Affectors", "_particle-_scripts.html#Particle-Affectors", null ],
      [ "Standard Particle Affectors", "_particle-_scripts.html#Standard-Particle-Affectors", [
        [ "Linear Force Affector", "_particle-_scripts.html#Linear-Force-Affector", null ],
        [ "ColourFader Affector", "_particle-_scripts.html#ColourFader-Affector", null ],
        [ "ColourFader2 Affector", "_particle-_scripts.html#ColourFader2-Affector", null ],
        [ "Scaler Affector", "_particle-_scripts.html#Scaler-Affector", null ],
        [ "Rotator Affector", "_particle-_scripts.html#Rotator-Affector", null ],
        [ "ColourInterpolator Affector", "_particle-_scripts.html#ColourInterpolator-Affector", null ],
        [ "ColourImage Affector", "_particle-_scripts.html#ColourImage-Affector", null ],
        [ "DeflectorPlane Affector", "_particle-_scripts.html#DeflectorPlane-Affector", null ],
        [ "DirectionRandomiser Affector", "_particle-_scripts.html#DirectionRandomiser-Affector", null ],
        [ "TextureAnimator Affector", "_particle-_scripts.html#TextureAnimator-Affector", null ]
      ] ]
    ] ],
    [ "Overlay Scripts", "_overlay-_scripts.html", [
      [ "Adding elements to the overlay", "_overlay-_scripts.html#Adding-elements-to-the-overlay", [
        [ "’overlay_element’ blocks", "_overlay-_scripts.html#autotoc_md96", null ]
      ] ],
      [ "Templates", "_overlay-_scripts.html#Templates", [
        [ "OverlayElement Attributes", "_overlay-_scripts.html#autotoc_md97", null ],
        [ "metrics_mode", "_overlay-_scripts.html#autotoc_md98", null ],
        [ "horz_align", "_overlay-_scripts.html#autotoc_md99", null ],
        [ "vert_align", "_overlay-_scripts.html#autotoc_md100", null ],
        [ "left", "_overlay-_scripts.html#autotoc_md101", null ],
        [ "top", "_overlay-_scripts.html#autotoc_md102", null ],
        [ "width", "_overlay-_scripts.html#autotoc_md103", null ],
        [ "height", "_overlay-_scripts.html#autotoc_md104", null ],
        [ "material", "_overlay-_scripts.html#autotoc_md105", null ],
        [ "caption", "_overlay-_scripts.html#autotoc_md106", null ],
        [ "rotation", "_overlay-_scripts.html#autotoc_md107", null ]
      ] ],
      [ "Standard OverlayElements", "_overlay-_scripts.html#Standard-OverlayElements", [
        [ "Panel (container)", "_overlay-_scripts.html#Panel", null ],
        [ "BorderPanel (container)", "_overlay-_scripts.html#BorderPanel", null ],
        [ "TextArea (element)", "_overlay-_scripts.html#TextArea", null ]
      ] ]
    ] ],
    [ "Font Definition Scripts", "_font-_definition-_scripts.html", [
      [ "Using an existing font texture", "_font-_definition-_scripts.html#autotoc_md108", null ],
      [ "Generating a font texture", "_font-_definition-_scripts.html#autotoc_md109", null ]
    ] ]
];